summaryrefslogtreecommitdiffstats
path: root/src/kernel/basesegment.C
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/basesegment.C')
-rw-r--r--src/kernel/basesegment.C12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/kernel/basesegment.C b/src/kernel/basesegment.C
index 90d61f1b2..2de6973e0 100644
--- a/src/kernel/basesegment.C
+++ b/src/kernel/basesegment.C
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2011,2016 */
+/* Contributors Listed Below - COPYRIGHT 2011,2017 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -236,16 +236,16 @@ int BaseSegment::mmExtend(void)
/**
* Allocates a block of virtual memory of the given size
* to extend the VMM to 32MEG in size in mainstore
*/
int BaseSegment::_mmExtend(void)
{
// The base address of the extended memory is 8Mg.. The first x pages is
// for the SPTE.. The remaining pages from 8MG + SPTE to 32MEG is added to
// the HEAP..
uint64_t l_vaddr = VMM_ADDR_EXTEND_BLOCK; // 8MEG
- uint64_t l_size = VMM_EXTEND_BLOCK_SIZE; // 32MEG - 8MB (base block)
+ uint64_t l_size = VMM_EXTEND_BLOCK_SIZE; // 48MEG - 8MB (base block)
// Call to allocate a block passing in the requested address of where the
// SPTEs should be created
@@ -283,14 +283,14 @@ int BaseSegment::_mmExtend(void)
PageManager::addMemory(l_vaddr + (spte_pages*PAGESIZE),
l_size/PAGESIZE - spte_pages);
// Update the physical Memory size to now be 32MEG. by adding the extended
// block size to the physical mem size.
iv_physMemSize += VMM_EXTEND_BLOCK_SIZE;
// Call to set the Hostboot MemSize and location needed for DUMP.
KernelMemState::setMemScratchReg(KernelMemState::MEM_CONTAINED_MS,
- KernelMemState::MS_32MEG);
+ KernelMemState::MS_48MEG);
return 0;
}
OpenPOWER on IntegriCloud
@@ -236,16 +236,16 @@ int BaseSegment::mmExtend(void)
/**
* Allocates a block of virtual memory of the given size
- * to extend the VMM to 32MEG in size in mainstore
+ * to extend the VMM to 48MEG in size in mainstore
*/
int BaseSegment::_mmExtend(void)
@@ -236,16 +236,16 @@ int BaseSegment::mmExtend(void)
{
// The base address of the extended memory is 8Mg.. The first x pages is
- // for the SPTE.. The remaining pages from 8MG + SPTE to 32MEG is added to
+ // for the SPTE.. The remaining pages from 8MG + SPTE to 48MEG is added to
// the HEAP..
uint64_t l_vaddr = VMM_ADDR_EXTEND_BLOCK; // 8MEG
@@ -283,14 +283,14 @@ int BaseSegment::_mmExtend(void)
PageManager::addMemory(l_vaddr + (spte_pages*PAGESIZE),
l_size/PAGESIZE - spte_pages);
- // Update the physical Memory size to now be 32MEG. by adding the extended
+ // Update the physical Memory size to now be 48MEG. by adding the extended
// block size to the physical mem size.
iv_physMemSize += VMM_EXTEND_BLOCK_SIZE;